"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, id_: str, wireless_gateway_task_definition_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a task for a wireless gateway.

    Args:
        id_(str): The ID of the resource to update.
        wireless_gateway_task_definition_id(str): The ID of the WirelessGatewayTaskDefinition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.task.init.create(
                ctx, id_=value, wireless_gateway_task_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.task.init.create id_=value, wireless_gateway_task_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="create_wireless_gateway_task",
        op_kwargs={
            "Id": id_,
            "WirelessGatewayTaskDefinitionId": wireless_gateway_task_definition_id,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a wireless gateway task.

    Args:
        id_(str): The ID of the resource to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.task.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.task.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="delete_wireless_gateway_task",
        op_kwargs={"Id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a wireless gateway task.

    Args:
        id_(str): The ID of the resource to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.task.init.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.task.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="get_wireless_gateway_task",
        op_kwargs={"Id": id_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, topic_arn: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the subscriptions to a specific topic. Each call returns a limited list of subscriptions, up to 100. If there are more subscriptions, a NextToken is also returned. Use the NextToken parameter in a new ListSubscriptionsByTopic call to get further results. This action is throttled at 30 transactions per second (TPS).

    Args:
        topic_arn(str): The ARN of the topic for which you wish to find subscriptions.
        next_token(str, optional): Token returned by the previous ListSubscriptionsByTopic request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.subscription.by_topic.list(ctx, topic_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.subscription.by_topic.list topic_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="list_subscriptions_by_topic",
        op_kwargs={"TopicArn": topic_arn, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def rotate(hub, ctx, id_: str, ingest_endpoint_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Rotate the IngestEndpoint's username and password, as specified by the IngestEndpoint's id.

    Args:
        id_(str): The ID of the channel the IngestEndpoint is on.
        ingest_endpoint_id(str): The id of the IngestEndpoint whose credentials should be rotated.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage.ingest_endpoint_credential.rotate(
                ctx, id_=value, ingest_endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage.ingest_endpoint_credential.rotate id_=value, ingest_endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage",
        operation="rotate_ingest_endpoint_credentials",
        op_kwargs={"Id": id_, "IngestEndpointId": ingest_endpoint_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, key_id: str, limit: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns all tags on the specified customer master key (CMK). For general information about tags, including the format and syntax, see Tagging AWS resources in the Amazon Web Services General Reference. For information about using tags in AWS KMS, see Tagging keys.  Cross-account use: No. You cannot perform this operation on a CMK in a different AWS account.  Required permissions: kms:ListResourceTags (key policy)  Related operations:     CreateKey     ReplicateKey     TagResource     UntagResource

    Args:
        key_id(str): Gets tags on the specified customer master key (CMK). Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
        limit(int, optional): Use this parameter to specify the maximum number of items to return. When this value is present, AWS KMS does not return more than the specified number of items, but it might return fewer. This value is optional. If you include a value, it must be between 1 and 50, inclusive. If you do not include a value, it defaults to 50. Defaults to None.
        marker(str, optional): Use this parameter in a subsequent request after you receive a response with truncated results. Set it to the value of NextMarker from the truncated response you just received. Do not attempt to construct this value. Use only the value of NextMarker from the truncated response you just received. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.resource.tag.list_all(ctx, key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.resource.tag.list_all key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="list_resource_tags",
        op_kwargs={"KeyId": key_id, "Limit": limit, "Marker": marker},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def apply(
    hub, ctx, resource_identifier: str, apply_action: str, opt_in_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Applies a pending maintenance action to a resource (for example, to a DB instance).

    Args:
        resource_identifier(str): The RDS Amazon Resource Name (ARN) of the resource that the pending maintenance action applies to. For information about creating an ARN, see  Constructing an RDS Amazon Resource Name (ARN).
        apply_action(str): The pending maintenance action to apply to this resource. Valid values: system-update, db-upgrade, hardware-maintenance, ca-certificate-rotation .
        opt_in_type(str): A value that specifies the type of opt-in request, or undoes an opt-in request. An opt-in request of type immediate can't be undone. Valid values:    immediate - Apply the maintenance action immediately.    next-maintenance - Apply the maintenance action during the next maintenance window for the resource.    undo-opt-in - Cancel any existing next-maintenance opt-in requests.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.pending_maintenance_action.apply(
                ctx, resource_identifier=value, apply_action=value, opt_in_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.pending_maintenance_action.apply resource_identifier=value, apply_action=value, opt_in_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="apply_pending_maintenance_action",
        op_kwargs={
            "ResourceIdentifier": resource_identifier,
            "ApplyAction": apply_action,
            "OptInType": opt_in_type,
        },
    )


async def describe_all(
    hub,
    ctx,
    resource_identifier: str = None,
    filters: List = None,
    marker: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of resources (for example, DB instances) that have at least one pending maintenance action.

    Args:
        resource_identifier(str, optional): The ARN of a resource to return pending maintenance actions for. Defaults to None.
        filters(List, optional): A filter that specifies one or more resources to return pending maintenance actions for. Supported filters:    db-cluster-id - Accepts DB cluster identifiers and DB cluster Amazon Resource Names (ARNs). The results list will only include pending maintenance actions for the DB clusters identified by these ARNs.    db-instance-id - Accepts DB instance identifiers and DB instance ARNs. The results list will only include pending maintenance actions for the DB instances identified by these ARNs.  . Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribePendingMaintenanceActions request. If this parameter is specified, the response includes only records beyond the marker, up to a number of records specified by MaxRecords. . Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.pending_maintenance_action.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.pending_maintenance_action.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_pending_maintenance_actions",
        op_kwargs={
            "ResourceIdentifier": resource_identifier,
            "Filters": filters,
            "Marker": marker,
            "MaxRecords": max_records,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, capacity_reservation_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the specified Capacity Reservation, releases the reserved capacity, and changes the Capacity Reservation's state to cancelled. Instances running in the reserved capacity continue running until you stop them. Stopped instances that target the Capacity Reservation can no longer launch. Modify these instances to either target a different Capacity Reservation, launch On-Demand Instance capacity, or run in any open Capacity Reservation that has matching attributes and sufficient capacity.

    Args:
        capacity_reservation_id(str): The ID of the Capacity Reservation to be cancelled.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.capacity_reservation.init.cancel(
                ctx, capacity_reservation_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.capacity_reservation.init.cancel capacity_reservation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="cancel_capacity_reservation",
        op_kwargs={"CapacityReservationId": capacity_reservation_id, "DryRun": dry_run},
    )


async def create(
    hub,
    ctx,
    instance_type: str,
    instance_platform: str,
    instance_count: int,
    client_token: str = None,
    availability_zone: str = None,
    availability_zone_id: str = None,
    tenancy: str = None,
    ebs_optimized: bool = None,
    ephemeral_storage: bool = None,
    end_date: str = None,
    end_date_type: str = None,
    instance_match_criteria: str = None,
    tag_specifications: List = None,
    dry_run: bool = None,
    outpost_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Capacity Reservation with the specified attributes. Capacity Reservations enable you to reserve capacity for your Amazon EC2 instances in a specific Availability Zone for any duration. This gives you the flexibility to selectively add capacity reservations and still get the Regional RI discounts for that usage. By creating Capacity Reservations, you ensure that you always have access to Amazon EC2 capacity when you need it, for as long as you need it. For more information, see Capacity Reservations in the Amazon EC2 User Guide. Your request to create a Capacity Reservation could fail if Amazon EC2 does not have sufficient capacity to fulfill the request. If your request fails due to Amazon EC2 capacity constraints, either try again at a later time, try in a different Availability Zone, or request a smaller capacity reservation. If your application is flexible across instance types and sizes, try to create a Capacity Reservation with different instance attributes. Your request could also fail if the requested quantity exceeds your On-Demand Instance limit for the selected instance type. If your request fails due to limit constraints, increase your On-Demand Instance limit for the required instance type and try again. For more information about increasing your instance limits, see Amazon EC2 Service Quotas in the Amazon EC2 User Guide.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensure Idempotency. Defaults to None.
        instance_type(str): The instance type for which to reserve capacity. For more information, see Instance types in the Amazon EC2 User Guide.
        instance_platform(str): The type of operating system for which to reserve capacity.
        availability_zone(str, optional): The Availability Zone in which to create the Capacity Reservation. Defaults to None.
        availability_zone_id(str, optional): The ID of the Availability Zone in which to create the Capacity Reservation. Defaults to None.
        tenancy(str, optional): Indicates the tenancy of the Capacity Reservation. A Capacity Reservation can have one of the following tenancy settings:    default - The Capacity Reservation is created on hardware that is shared with other Amazon Web Services accounts.    dedicated - The Capacity Reservation is created on single-tenant hardware that is dedicated to a single Amazon Web Services account.  . Defaults to None.
        instance_count(int): The number of instances for which to reserve capacity.
        ebs_optimized(bool, optional): Indicates whether the Capacity Reservation supports EBS-optimized instances. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS- optimized instance. Defaults to None.
        ephemeral_storage(bool, optional): Indicates whether the Capacity Reservation supports instances with temporary, block-level storage. Defaults to None.
        end_date(str, optional): The date and time at which the Capacity Reservation expires. When a Capacity Reservation expires, the reserved capacity is released and you can no longer launch instances into it. The Capacity Reservation's state changes to expired when it reaches its end date and time. You must provide an EndDate value if EndDateType is limited. Omit EndDate if EndDateType is unlimited. If the EndDateType is limited, the Capacity Reservation is cancelled within an hour from the specified time. For example, if you specify 5/31/2019, 13:30:55, the Capacity Reservation is guaranteed to end between 13:30:55 and 14:30:55 on 5/31/2019. Defaults to None.
        end_date_type(str, optional): Indicates the way in which the Capacity Reservation ends. A Capacity Reservation can have one of the following end types:    unlimited - The Capacity Reservation remains active until you explicitly cancel it. Do not provide an EndDate if the EndDateType is unlimited.    limited - The Capacity Reservation expires automatically at a specified date and time. You must provide an EndDate value if the EndDateType value is limited.  . Defaults to None.
        instance_match_criteria(str, optional): Indicates the type of instance launches that the Capacity Reservation accepts. The options include:    open - The Capacity Reservation automatically matches all instances that have matching attributes (instance type, platform, and Availability Zone). Instances that have matching attributes run in the Capacity Reservation automatically without specifying any additional parameters.    targeted - The Capacity Reservation only accepts instances that have matching attributes (instance type, platform, and Availability Zone), and explicitly target the Capacity Reservation. This ensures that only permitted instances can use the reserved capacity.    Default: open . Defaults to None.
        tag_specifications(List, optional): The tags to apply to the Capacity Reservation during launch. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        outpost_arn(str, optional): The Amazon Resource Name (ARN) of the Outpost on which to create the Capacity Reservation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.capacity_reservation.init.create(
                ctx, instance_type=value, instance_platform=value, instance_count=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.capacity_reservation.init.create instance_type=value, instance_platform=value, instance_count=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_capacity_reservation",
        op_kwargs={
            "ClientToken": client_token,
            "InstanceType": instance_type,
            "InstancePlatform": instance_platform,
            "AvailabilityZone": availability_zone,
            "AvailabilityZoneId": availability_zone_id,
            "Tenancy": tenancy,
            "InstanceCount": instance_count,
            "EbsOptimized": ebs_optimized,
            "EphemeralStorage": ephemeral_storage,
            "EndDate": end_date,
            "EndDateType": end_date_type,
            "InstanceMatchCriteria": instance_match_criteria,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
            "OutpostArn": outpost_arn,
        },
    )


async def describe_all(
    hub,
    ctx,
    capacity_reservation_ids: List = None,
    next_token: str = None,
    max_results: int = None,
    filters: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your Capacity Reservations. The results describe only the Capacity Reservations in the Amazon Web Services Region that you're currently using.

    Args:
        capacity_reservation_ids(List, optional): The ID of the Capacity Reservation. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value. This value can be between 5 and 500. If maxResults is given a larger value than 500, you receive an error. Defaults to None.
        filters(List, optional): One or more filters.    instance-type - The type of instance for which the Capacity Reservation reserves capacity.    owner-id - The ID of the Amazon Web Services account that owns the Capacity Reservation.    availability-zone-id - The Availability Zone ID of the Capacity Reservation.    instance-platform - The type of operating system for which the Capacity Reservation reserves capacity.    availability-zone - The Availability Zone ID of the Capacity Reservation.    tenancy - Indicates the tenancy of the Capacity Reservation. A Capacity Reservation can have one of the following tenancy settings:    default - The Capacity Reservation is created on hardware that is shared with other Amazon Web Services accounts.    dedicated - The Capacity Reservation is created on single-tenant hardware that is dedicated to a single Amazon Web Services account.      outpost-arn - The Amazon Resource Name (ARN) of the Outpost on which the Capacity Reservation was created.    state - The current state of the Capacity Reservation. A Capacity Reservation can be in one of the following states:    active- The Capacity Reservation is active and the capacity is available for your use.    expired - The Capacity Reservation expired automatically at the date and time specified in your request. The reserved capacity is no longer available for your use.    cancelled - The Capacity Reservation was cancelled. The reserved capacity is no longer available for your use.    pending - The Capacity Reservation request was successful but the capacity provisioning is still pending.    failed - The Capacity Reservation request has failed. A request might fail due to invalid request parameters, capacity constraints, or instance limit constraints. Failed requests are retained for 60 minutes.      start-date - The date and time at which the Capacity Reservation was started.    end-date - The date and time at which the Capacity Reservation expires. When a Capacity Reservation expires, the reserved capacity is released and you can no longer launch instances into it. The Capacity Reservation's state changes to expired when it reaches its end date and time.    end-date-type - Indicates the way in which the Capacity Reservation ends. A Capacity Reservation can have one of the following end types:    unlimited - The Capacity Reservation remains active until you explicitly cancel it.    limited - The Capacity Reservation expires automatically at a specified date and time.      instance-match-criteria - Indicates the type of instance launches that the Capacity Reservation accepts. The options include:    open - The Capacity Reservation accepts all instances that have matching attributes (instance type, platform, and Availability Zone). Instances that have matching attributes launch into the Capacity Reservation automatically without specifying any additional parameters.    targeted - The Capacity Reservation only accepts instances that have matching attributes (instance type, platform, and Availability Zone), and explicitly target the Capacity Reservation. This ensures that only permitted instances can use the reserved capacity.    . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.capacity_reservation.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.capacity_reservation.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_capacity_reservations",
        op_kwargs={
            "CapacityReservationIds": capacity_reservation_ids,
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
            "DryRun": dry_run,
        },
    )


async def modify(
    hub,
    ctx,
    capacity_reservation_id: str,
    instance_count: int = None,
    end_date: str = None,
    end_date_type: str = None,
    accept: bool = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies a Capacity Reservation's capacity and the conditions under which it is to be released. You cannot change a Capacity Reservation's instance type, EBS optimization, instance store settings, platform, Availability Zone, or instance eligibility. If you need to modify any of these attributes, we recommend that you cancel the Capacity Reservation, and then create a new one with the required attributes.

    Args:
        capacity_reservation_id(str): The ID of the Capacity Reservation.
        instance_count(int, optional): The number of instances for which to reserve capacity. Defaults to None.
        end_date(str, optional): The date and time at which the Capacity Reservation expires. When a Capacity Reservation expires, the reserved capacity is released and you can no longer launch instances into it. The Capacity Reservation's state changes to expired when it reaches its end date and time. The Capacity Reservation is cancelled within an hour from the specified time. For example, if you specify 5/31/2019, 13:30:55, the Capacity Reservation is guaranteed to end between 13:30:55 and 14:30:55 on 5/31/2019. You must provide an EndDate value if EndDateType is limited. Omit EndDate if EndDateType is unlimited. Defaults to None.
        end_date_type(str, optional): Indicates the way in which the Capacity Reservation ends. A Capacity Reservation can have one of the following end types:    unlimited - The Capacity Reservation remains active until you explicitly cancel it. Do not provide an EndDate value if EndDateType is unlimited.    limited - The Capacity Reservation expires automatically at a specified date and time. You must provide an EndDate value if EndDateType is limited.  . Defaults to None.
        accept(bool, optional): Reserved. Capacity Reservations you have created are accepted by default. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.capacity_reservation.init.modify(
                ctx, capacity_reservation_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.capacity_reservation.init.modify capacity_reservation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_capacity_reservation",
        op_kwargs={
            "CapacityReservationId": capacity_reservation_id,
            "InstanceCount": instance_count,
            "EndDate": end_date,
            "EndDateType": end_date_type,
            "Accept": accept,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    reserved_cache_node_id: str = None,
    reserved_cache_nodes_offering_id: str = None,
    cache_node_type: str = None,
    duration: str = None,
    product_description: str = None,
    offering_type: str = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about reserved cache nodes for this account, or about a specified reserved cache node.

    Args:
        reserved_cache_node_id(str, optional): The reserved cache node identifier filter value. Use this parameter to show only the reservation that matches the specified reservation ID. Defaults to None.
        reserved_cache_nodes_offering_id(str, optional): The offering identifier filter value. Use this parameter to show only purchased reservations matching the specified offering identifier. Defaults to None.
        cache_node_type(str, optional): The cache node type filter value. Use this parameter to show only those reservations matching the specified cache node type. The following node types are supported by ElastiCache. Generally speaking, the current generation types provide more memory and computational power at lower cost when compared to their equivalent previous generation counterparts.   General purpose:   Current generation:   M6g node types (available only for Redis engine version 5.0.6 onward and for Memcached engine version 1.5.16 onward).  cache.m6g.large, cache.m6g.xlarge, cache.m6g.2xlarge, cache.m6g.4xlarge, cache.m6g.8xlarge, cache.m6g.12xlarge, cache.m6g.16xlarge   For region availability, see Supported Node Types    M5 node types: cache.m5.large, cache.m5.xlarge, cache.m5.2xlarge, cache.m5.4xlarge, cache.m5.12xlarge, cache.m5.24xlarge   M4 node types: cache.m4.large, cache.m4.xlarge, cache.m4.2xlarge, cache.m4.4xlarge, cache.m4.10xlarge   T3 node types: cache.t3.micro, cache.t3.small, cache.t3.medium   T2 node types: cache.t2.micro, cache.t2.small, cache.t2.medium    Previous generation: (not recommended)  T1 node types: cache.t1.micro   M1 node types: cache.m1.small, cache.m1.medium, cache.m1.large, cache.m1.xlarge   M3 node types: cache.m3.medium, cache.m3.large, cache.m3.xlarge, cache.m3.2xlarge      Compute optimized:   Previous generation: (not recommended)  C1 node types: cache.c1.xlarge      Memory optimized:   Current generation:   R6g node types (available only for Redis engine version 5.0.6 onward and for Memcached engine version 1.5.16 onward).  cache.r6g.large, cache.r6g.xlarge, cache.r6g.2xlarge, cache.r6g.4xlarge, cache.r6g.8xlarge, cache.r6g.12xlarge, cache.r6g.16xlarge   For region availability, see Supported Node Types    R5 node types: cache.r5.large, cache.r5.xlarge, cache.r5.2xlarge, cache.r5.4xlarge, cache.r5.12xlarge, cache.r5.24xlarge   R4 node types: cache.r4.large, cache.r4.xlarge, cache.r4.2xlarge, cache.r4.4xlarge, cache.r4.8xlarge, cache.r4.16xlarge    Previous generation: (not recommended)  M2 node types: cache.m2.xlarge, cache.m2.2xlarge, cache.m2.4xlarge   R3 node types: cache.r3.large, cache.r3.xlarge, cache.r3.2xlarge, cache.r3.4xlarge, cache.r3.8xlarge       Additional node type info    All current generation instance types are created in Amazon VPC by default.   Redis append-only files (AOF) are not supported for T1 or T2 instances.   Redis Multi-AZ with automatic failover is not supported on T1 instances.   Redis configuration variables appendonly and appendfsync are not supported on Redis version 2.8.22 and later.  . Defaults to None.
        duration(str, optional): The duration filter value, specified in years or seconds. Use this parameter to show only reservations for this duration. Valid Values: 1 | 3 | 31536000 | 94608000 . Defaults to None.
        product_description(str, optional): The product description filter value. Use this parameter to show only those reservations matching the specified product description. Defaults to None.
        offering_type(str, optional): The offering type filter value. Use this parameter to show only the available offerings matching the specified offering type. Valid values: "Light Utilization"|"Medium Utilization"|"Heavy Utilization"|"All Upfront"|"Partial Upfront"| "No Upfront" . Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: minimum 20; maximum 100. Defaults to None.
        marker(str, optional): An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.reserved_cache_node.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.reserved_cache_node.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="describe_reserved_cache_nodes",
        op_kwargs={
            "ReservedCacheNodeId": reserved_cache_node_id,
            "ReservedCacheNodesOfferingId": reserved_cache_nodes_offering_id,
            "CacheNodeType": cache_node_type,
            "Duration": duration,
            "ProductDescription": product_description,
            "OfferingType": offering_type,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def check(hub, ctx, scope: str, rules: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns the web ACL capacity unit (WCU) requirements for a specified scope and set of rules. You can use this to check the capacity requirements for the rules you want to use in a RuleGroup or WebACL.  WAF uses WCUs to calculate and control the operating resources that are used to run your rules, rule groups, and web ACLs. WAF calculates capacity differently for each rule type, to reflect the relative cost of each rule. Simple rules that cost little to run use fewer WCUs than more complex rules that use more processing power. Rule group capacity is fixed at creation, which helps users plan their web ACL WCU usage when they use a rule group. The WCU limit for web ACLs is 1,500.

    Args:
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        rules(List): An array of Rule that you're configuring to use in a rule group or web ACL. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.capacity.check(ctx, scope=value, rules=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.capacity.check scope=value, rules=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="check_capacity",
        op_kwargs={"Scope": scope, "Rules": rules},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, dataset_name: str, version_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates the content of a dataset by applying a queryAction (a SQL query) or a containerAction (executing a containerized application).

    Args:
        dataset_name(str): The name of the dataset.
        version_id(str, optional): The version ID of the dataset content. To specify versionId for a dataset content, the dataset must use a DeltaTimer filter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.dataset.content.create(ctx, dataset_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.dataset.content.create dataset_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="create_dataset_content",
        op_kwargs={"datasetName": dataset_name, "versionId": version_id},
    )


async def delete(hub, ctx, dataset_name: str, version_id: str = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the content of the specified dataset.

    Args:
        dataset_name(str): The name of the dataset whose content is deleted.
        version_id(str, optional): The version of the dataset whose content is deleted. You can also use the strings "$LATEST" or "$LATEST_SUCCEEDED" to delete the latest or latest successfully completed data set. If not specified, "$LATEST_SUCCEEDED" is the default. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.dataset.content.delete(ctx, dataset_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.dataset.content.delete dataset_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="delete_dataset_content",
        op_kwargs={"datasetName": dataset_name, "versionId": version_id},
    )


async def get(hub, ctx, dataset_name: str, version_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the contents of a dataset as presigned URIs.

    Args:
        dataset_name(str): The name of the dataset whose contents are retrieved.
        version_id(str, optional): The version of the dataset whose contents are retrieved. You can also use the strings "$LATEST" or "$LATEST_SUCCEEDED" to retrieve the contents of the latest or latest successfully completed dataset. If not specified, "$LATEST_SUCCEEDED" is the default. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.dataset.content.get(ctx, dataset_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.dataset.content.get dataset_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="get_dataset_content",
        op_kwargs={"datasetName": dataset_name, "versionId": version_id},
    )


async def list_all(
    hub,
    ctx,
    dataset_name: str,
    next_token: str = None,
    max_results: int = None,
    scheduled_on_or_after: str = None,
    scheduled_before: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists information about dataset contents that have been created.

    Args:
        dataset_name(str): The name of the dataset whose contents information you want to list.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this request. Defaults to None.
        scheduled_on_or_after(str, optional): A filter to limit results to those dataset contents whose creation is scheduled on or after the given time. See the field triggers.schedule in the CreateDataset request. (timestamp). Defaults to None.
        scheduled_before(str, optional): A filter to limit results to those dataset contents whose creation is scheduled before the given time. See the field triggers.schedule in the CreateDataset request. (timestamp). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.dataset.content.list_all(ctx, dataset_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.dataset.content.list_all dataset_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="list_dataset_contents",
        op_kwargs={
            "datasetName": dataset_name,
            "nextToken": next_token,
            "maxResults": max_results,
            "scheduledOnOrAfter": scheduled_on_or_after,
            "scheduledBefore": scheduled_before,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub,
    ctx,
    vpn_connection_id: str,
    local_ipv4_network_cidr: str = None,
    remote_ipv4_network_cidr: str = None,
    local_ipv6_network_cidr: str = None,
    remote_ipv6_network_cidr: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the connection options for your Site-to-Site VPN connection. When you modify the VPN connection options, the VPN endpoint IP addresses on the AWS side do not change, and the tunnel options do not change. Your VPN connection will be temporarily unavailable for a brief period while the VPN connection is updated.

    Args:
        vpn_connection_id(str): The ID of the Site-to-Site VPN connection. .
        local_ipv4_network_cidr(str, optional): The IPv4 CIDR on the customer gateway (on-premises) side of the VPN connection. Default: 0.0.0.0/0 . Defaults to None.
        remote_ipv4_network_cidr(str, optional): The IPv4 CIDR on the AWS side of the VPN connection. Default: 0.0.0.0/0 . Defaults to None.
        local_ipv6_network_cidr(str, optional): The IPv6 CIDR on the customer gateway (on-premises) side of the VPN connection. Default: ::/0 . Defaults to None.
        remote_ipv6_network_cidr(str, optional): The IPv6 CIDR on the AWS side of the VPN connection. Default: ::/0 . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpn.connection.option.modify(ctx, vpn_connection_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpn.connection.option.modify vpn_connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_vpn_connection_options",
        op_kwargs={
            "VpnConnectionId": vpn_connection_id,
            "LocalIpv4NetworkCidr": local_ipv4_network_cidr,
            "RemoteIpv4NetworkCidr": remote_ipv4_network_cidr,
            "LocalIpv6NetworkCidr": local_ipv6_network_cidr,
            "RemoteIpv6NetworkCidr": remote_ipv6_network_cidr,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, job_name: str, dataset_arn: str, data_source: Dict, role_arn: str
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a job that imports training data from your data source (an Amazon S3 bucket) to an Amazon Personalize dataset. To allow Amazon Personalize to import the training data, you must specify an IAM service role that has permission to read from the data source, as Amazon Personalize makes a copy of your data and processes it internally. For information on granting access to your Amazon S3 bucket, see Giving Amazon Personalize Access to Amazon S3 Resources.   The dataset import job replaces any existing data in the dataset that you imported in bulk.   Status  A dataset import job can be in one of the following states:   CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED   To get the status of the import job, call DescribeDatasetImportJob, providing the Amazon Resource Name (ARN) of the dataset import job. The dataset import is complete when the status shows as ACTIVE. If the status shows as CREATE FAILED, the response includes a failureReason key, which describes why the job failed.  Importing takes time. You must wait until the status shows as ACTIVE before training a model using the dataset.   Related APIs     ListDatasetImportJobs     DescribeDatasetImportJob

    Args:
        job_name(str): The name for the dataset import job.
        dataset_arn(str): The ARN of the dataset that receives the imported data.
        data_source(Dict): The Amazon S3 bucket that contains the training data to import.
        role_arn(str): The ARN of the IAM role that has permissions to read from the Amazon S3 data source.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.dataset.import_job.create(
                ctx, job_name=value, dataset_arn=value, data_source=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.dataset.import_job.create job_name=value, dataset_arn=value, data_source=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="create_dataset_import_job",
        op_kwargs={
            "jobName": job_name,
            "datasetArn": dataset_arn,
            "dataSource": data_source,
            "roleArn": role_arn,
        },
    )


async def describe(hub, ctx, dataset_import_job_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the dataset import job created by CreateDatasetImportJob, including the import job status.

    Args:
        dataset_import_job_arn(str): The Amazon Resource Name (ARN) of the dataset import job to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.dataset.import_job.describe(
                ctx, dataset_import_job_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.dataset.import_job.describe dataset_import_job_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="describe_dataset_import_job",
        op_kwargs={"datasetImportJobArn": dataset_import_job_arn},
    )


async def list_all(
    hub, ctx, dataset_arn: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of dataset import jobs that use the given dataset. When a dataset is not specified, all the dataset import jobs associated with the account are listed. The response provides the properties for each dataset import job, including the Amazon Resource Name (ARN). For more information on dataset import jobs, see CreateDatasetImportJob. For more information on datasets, see CreateDataset.

    Args:
        dataset_arn(str, optional): The Amazon Resource Name (ARN) of the dataset to list the dataset import jobs for. Defaults to None.
        next_token(str, optional): A token returned from the previous call to ListDatasetImportJobs for getting the next set of dataset import jobs (if they exist). Defaults to None.
        max_results(int, optional): The maximum number of dataset import jobs to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.dataset.import_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.dataset.import_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="list_dataset_import_jobs",
        op_kwargs={
            "datasetArn": dataset_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def allow(
    hub,
    ctx,
    endpoint_group_arn: str,
    endpoint_id: str,
    destination_addresses: List = None,
    destination_ports: List = None,
    allow_all_traffic_to_endpoint: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Specify the Amazon EC2 instance (destination) IP addresses and ports for a VPC subnet endpoint that can receive traffic for a custom routing accelerator. You can allow traffic to all destinations in the subnet endpoint, or allow traffic to a specified list of destination IP addresses and ports in the subnet. Note that you cannot specify IP addresses or ports outside of the range that you configured for the endpoint group. After you make changes, you can verify that the updates are complete by checking the status of your accelerator: the status changes from IN_PROGRESS to DEPLOYED.

    Args:
        endpoint_group_arn(str): The Amazon Resource Name (ARN) of the endpoint group.
        endpoint_id(str): An ID for the endpoint. For custom routing accelerators, this is the virtual private cloud (VPC) subnet ID.
        destination_addresses(List, optional): A list of specific Amazon EC2 instance IP addresses (destination addresses) in a subnet that you want to allow to receive traffic. The IP addresses must be a subset of the IP addresses that you specified for the endpoint group.  DestinationAddresses is required if AllowAllTrafficToEndpoint is FALSE or is not specified. Defaults to None.
        destination_ports(List, optional): A list of specific Amazon EC2 instance ports (destination ports) that you want to allow to receive traffic. Defaults to None.
        allow_all_traffic_to_endpoint(bool, optional): Indicates whether all destination IP addresses and ports for a specified VPC subnet endpoint can receive traffic from a custom routing accelerator. The value is TRUE or FALSE.  When set to TRUE, all destinations in the custom routing VPC subnet can receive traffic. Note that you cannot specify destination IP addresses and ports when the value is set to TRUE. When set to FALSE (or not specified), you must specify a list of destination IP addresses that are allowed to receive traffic. A list of ports is optional. If you don't specify a list of ports, the ports that can accept traffic is the same as the ports configured for the endpoint group. The default value is FALSE. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.traffic.allow(
                ctx, endpoint_group_arn=value, endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.traffic.allow endpoint_group_arn=value, endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="allow_custom_routing_traffic",
        op_kwargs={
            "EndpointGroupArn": endpoint_group_arn,
            "EndpointId": endpoint_id,
            "DestinationAddresses": destination_addresses,
            "DestinationPorts": destination_ports,
            "AllowAllTrafficToEndpoint": allow_all_traffic_to_endpoint,
        },
    )


async def deny(
    hub,
    ctx,
    endpoint_group_arn: str,
    endpoint_id: str,
    destination_addresses: List = None,
    destination_ports: List = None,
    deny_all_traffic_to_endpoint: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Specify the Amazon EC2 instance (destination) IP addresses and ports for a VPC subnet endpoint that cannot receive traffic for a custom routing accelerator. You can deny traffic to all destinations in the VPC endpoint, or deny traffic to a specified list of destination IP addresses and ports. Note that you cannot specify IP addresses or ports outside of the range that you configured for the endpoint group. After you make changes, you can verify that the updates are complete by checking the status of your accelerator: the status changes from IN_PROGRESS to DEPLOYED.

    Args:
        endpoint_group_arn(str): The Amazon Resource Name (ARN) of the endpoint group.
        endpoint_id(str): An ID for the endpoint. For custom routing accelerators, this is the virtual private cloud (VPC) subnet ID.
        destination_addresses(List, optional): A list of specific Amazon EC2 instance IP addresses (destination addresses) in a subnet that you want to prevent from receiving traffic. The IP addresses must be a subset of the IP addresses allowed for the VPC subnet associated with the endpoint group. Defaults to None.
        destination_ports(List, optional): A list of specific Amazon EC2 instance ports (destination ports) in a subnet endpoint that you want to prevent from receiving traffic. Defaults to None.
        deny_all_traffic_to_endpoint(bool, optional): Indicates whether all destination IP addresses and ports for a specified VPC subnet endpoint cannot receive traffic from a custom routing accelerator. The value is TRUE or FALSE.  When set to TRUE, no destinations in the custom routing VPC subnet can receive traffic. Note that you cannot specify destination IP addresses and ports when the value is set to TRUE. When set to FALSE (or not specified), you must specify a list of destination IP addresses that cannot receive traffic. A list of ports is optional. If you don't specify a list of ports, the ports that can accept traffic is the same as the ports configured for the endpoint group. The default value is FALSE. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.traffic.deny(
                ctx, endpoint_group_arn=value, endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.traffic.deny endpoint_group_arn=value, endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="deny_custom_routing_traffic",
        op_kwargs={
            "EndpointGroupArn": endpoint_group_arn,
            "EndpointId": endpoint_id,
            "DestinationAddresses": destination_addresses,
            "DestinationPorts": destination_ports,
            "DenyAllTrafficToEndpoint": deny_all_traffic_to_endpoint,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    target_arn: str,
    event_bus_name: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the rules for the specified target. You can see which of the rules in Amazon EventBridge can invoke a specific target in your account.

    Args:
        target_arn(str): The Amazon Resource Name (ARN) of the target resource.
        event_bus_name(str, optional): The name or ARN of the event bus to list rules for. If you omit this, the default event bus is used. Defaults to None.
        next_token(str, optional): The token returned by a previous call to retrieve the next set of results. Defaults to None.
        limit(int, optional): The maximum number of results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.rule.name_by_target.list(ctx, target_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.rule.name_by_target.list target_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="list_rule_names_by_target",
        op_kwargs={
            "TargetArn": target_arn,
            "EventBusName": event_bus_name,
            "NextToken": next_token,
            "Limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    prefix_list_name: str,
    max_entries: int,
    address_family: str,
    dry_run: bool = None,
    entries: List = None,
    tag_specifications: List = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a managed prefix list. You can specify one or more entries for the prefix list. Each entry consists of a CIDR block and an optional description. You must specify the maximum number of entries for the prefix list. The maximum number of entries cannot be changed later.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        prefix_list_name(str): A name for the prefix list. Constraints: Up to 255 characters in length. The name cannot start with com.amazonaws.
        entries(List, optional): One or more entries for the prefix list. Defaults to None.
        max_entries(int): The maximum number of entries for the prefix list.
        tag_specifications(List, optional): The tags to apply to the prefix list during creation. Defaults to None.
        address_family(str): The IP address type. Valid Values: IPv4 | IPv6 .
        client_token(str, optional): Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency. Constraints: Up to 255 UTF-8 characters in length. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.managed_prefix_list_.init.create(
                ctx, prefix_list_name=value, max_entries=value, address_family=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.managed_prefix_list_.init.create prefix_list_name=value, max_entries=value, address_family=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_managed_prefix_list",
        op_kwargs={
            "DryRun": dry_run,
            "PrefixListName": prefix_list_name,
            "Entries": entries,
            "MaxEntries": max_entries,
            "TagSpecifications": tag_specifications,
            "AddressFamily": address_family,
            "ClientToken": client_token,
        },
    )


async def delete(hub, ctx, prefix_list_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified managed prefix list. You must first remove all references to the prefix list in your resources.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        prefix_list_id(str): The ID of the prefix list.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.managed_prefix_list_.init.delete(ctx, prefix_list_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.managed_prefix_list_.init.delete prefix_list_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_managed_prefix_list",
        op_kwargs={"DryRun": dry_run, "PrefixListId": prefix_list_id},
    )


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    prefix_list_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes your managed prefix lists and any Amazon Web Services-managed prefix lists. To view the entries for your prefix list, use GetManagedPrefixListEntries.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filters(List, optional): One or more filters.    owner-id - The ID of the prefix list owner.    prefix-list-id - The ID of the prefix list.    prefix-list-name - The name of the prefix list.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        prefix_list_ids(List, optional): One or more prefix list IDs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.managed_prefix_list_.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.managed_prefix_list_.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_managed_prefix_lists",
        op_kwargs={
            "DryRun": dry_run,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "PrefixListIds": prefix_list_ids,
        },
    )


async def modify(
    hub,
    ctx,
    prefix_list_id: str,
    dry_run: bool = None,
    current_version: int = None,
    prefix_list_name: str = None,
    add_entries: List = None,
    remove_entries: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the specified managed prefix list. Adding or removing entries in a prefix list creates a new version of the prefix list. Changing the name of the prefix list does not affect the version. If you specify a current version number that does not match the true current version number, the request fails.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        prefix_list_id(str): The ID of the prefix list.
        current_version(int, optional): The current version of the prefix list. Defaults to None.
        prefix_list_name(str, optional): A name for the prefix list. Defaults to None.
        add_entries(List, optional): One or more entries to add to the prefix list. Defaults to None.
        remove_entries(List, optional): One or more entries to remove from the prefix list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.managed_prefix_list_.init.modify(ctx, prefix_list_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.managed_prefix_list_.init.modify prefix_list_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_managed_prefix_list",
        op_kwargs={
            "DryRun": dry_run,
            "PrefixListId": prefix_list_id,
            "CurrentVersion": current_version,
            "PrefixListName": prefix_list_name,
            "AddEntries": add_entries,
            "RemoveEntries": remove_entries,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def detect(
    hub, ctx, image: Dict, min_confidence: float = None, human_loop_config: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Detects unsafe content in a specified JPEG or PNG format image. Use DetectModerationLabels to moderate images depending on your requirements. For example, you might want to filter images that contain nudity, but not images containing suggestive content. To filter images, use the labels returned by DetectModerationLabels to determine which types of content are appropriate. For information about moderation labels, see Detecting Unsafe Content in the Amazon Rekognition Developer Guide. You pass the input image either as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the AWS CLI to call Amazon Rekognition operations, passing image bytes is not supported. The image must be either a PNG or JPEG formatted file.

    Args:
        image(Dict): The input image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes is not supported.  If you are using an AWS SDK to call Amazon Rekognition, you might not need to base64-encode image bytes passed using the Bytes field. For more information, see Images in the Amazon Rekognition developer guide.
        min_confidence(float, optional): Specifies the minimum confidence level for the labels to return. Amazon Rekognition doesn't return any labels with a confidence level lower than this specified value. If you don't specify MinConfidence, the operation returns labels with confidence values greater than or equal to 50 percent. Defaults to None.
        human_loop_config(Dict, optional): Sets up the configuration for human evaluation, including the FlowDefinition the image will be sent to. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.moderation_label.detect(ctx, image=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.moderation_label.detect image=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="detect_moderation_labels",
        op_kwargs={
            "Image": image,
            "MinConfidence": min_confidence,
            "HumanLoopConfig": human_loop_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, image_pipeline_arn: str, client_token: str) -> Dict:
    r"""
    **Autogenerated function**

     Manually triggers a pipeline to create an image.

    Args:
        image_pipeline_arn(str): The Amazon Resource Name (ARN) of the image pipeline that you want to manually invoke.
        client_token(str): The idempotency token used to make this request idempotent.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.pipeline.execution.start(
                ctx, image_pipeline_arn=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.pipeline.execution.start image_pipeline_arn=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="start_image_pipeline_execution",
        op_kwargs={"imagePipelineArn": image_pipeline_arn, "clientToken": client_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, role_name: str, description: str) -> Dict:
    r"""
    **Autogenerated function**

    Use UpdateRole instead. Modifies only the description of a role. This operation performs the same function as the Description parameter in the UpdateRole operation.

    Args:
        role_name(str): The name of the role that you want to modify.
        description(str): The new description that you want to apply to the specified role.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.role.description.update(
                ctx, role_name=value, description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.role.description.update role_name=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="update_role_description",
        op_kwargs={"RoleName": role_name, "Description": description},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    assessment_id: str,
    control_set_id: str,
    evidence_folder_id: str,
    evidence_id: str,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns evidence from Audit Manager.

    Args:
        assessment_id(str):  The identifier for the specified assessment. .
        control_set_id(str):  The identifier for the specified control set. .
        evidence_folder_id(str):  The identifier for the folder in which the evidence is stored. .
        evidence_id(str):  The identifier for the evidence. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.evidence.init.get(
                ctx,
                assessment_id=value,
                control_set_id=value,
                evidence_folder_id=value,
                evidence_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.evidence.init.get assessment_id=value, control_set_id=value, evidence_folder_id=value, evidence_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="get_evidence",
        op_kwargs={
            "assessmentId": assessment_id,
            "controlSetId": control_set_id,
            "evidenceFolderId": evidence_folder_id,
            "evidenceId": evidence_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def create(
    hub,
    ctx,
    long_term_pricing_type: str,
    is_long_term_pricing_auto_renew: bool = None,
    snowball_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a job with the long-term usage option for a device. The long-term usage is a 1-year or 3-year long-term pricing type for the device. You are billed upfront, and AWS provides discounts for long-term pricing.

    Args:
        long_term_pricing_type(str): The type of long-term pricing option you want for the device, either 1-year or 3-year long-term pricing.
        is_long_term_pricing_auto_renew(bool, optional): Specifies whether the current long-term pricing type for the device should be renewed. Defaults to None.
        snowball_type(str, optional): The type of AWS Snow Family device to use for the long-term pricing job. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.long_term_pricing.create(
                ctx, long_term_pricing_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.long_term_pricing.create long_term_pricing_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="create_long_term_pricing",
        op_kwargs={
            "LongTermPricingType": long_term_pricing_type,
            "IsLongTermPricingAutoRenew": is_long_term_pricing_auto_renew,
            "SnowballType": snowball_type,
        },
    )


async def list_(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all long-term pricing types.

    Args:
        max_results(int, optional): The maximum number of ListLongTermPricing objects to return. Defaults to None.
        next_token(str, optional): Because HTTP requests are stateless, this is the starting point for your next list of ListLongTermPricing to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.long_term_pricing.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.long_term_pricing.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="list_long_term_pricing",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    long_term_pricing_id: str,
    replacement_job: str = None,
    is_long_term_pricing_auto_renew: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the long-term pricing type.

    Args:
        long_term_pricing_id(str): The ID of the long-term pricing type for the device.
        replacement_job(str, optional): Specifies that a device that is ordered with long-term pricing should be replaced with a new device. Defaults to None.
        is_long_term_pricing_auto_renew(bool, optional): If set to true, specifies that the current long-term pricing type for the device should be automatically renewed before the long-term pricing contract expires. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.long_term_pricing.update(
                ctx, long_term_pricing_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.long_term_pricing.update long_term_pricing_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="update_long_term_pricing",
        op_kwargs={
            "LongTermPricingId": long_term_pricing_id,
            "ReplacementJob": replacement_job,
            "IsLongTermPricingAutoRenew": is_long_term_pricing_auto_renew,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    version_id: str,
    catalog_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified version of a table.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The database in the catalog in which the table resides. For Hive compatibility, this name is entirely lowercase.
        table_name(str): The name of the table. For Hive compatibility, this name is entirely lowercase.
        version_id(str): The ID of the table version to be deleted. A VersionID is a string representation of an integer. Each version is incremented by 1.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.table.version.delete(
                ctx, database_name=value, table_name=value, version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.table.version.delete database_name=value, table_name=value, version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_table_version",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableName": table_name,
            "VersionId": version_id,
        },
    )


async def get(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    catalog_id: str = None,
    version_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a specified version of a table.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The database in the catalog in which the table resides. For Hive compatibility, this name is entirely lowercase.
        table_name(str): The name of the table. For Hive compatibility, this name is entirely lowercase.
        version_id(str, optional): The ID value of the table version to be retrieved. A VersionID is a string representation of an integer. Each version is incremented by 1. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.table.version.get(
                ctx, database_name=value, table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.table.version.get database_name=value, table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_table_version",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableName": table_name,
            "VersionId": version_id,
        },
    )


async def get_all(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    catalog_id: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of strings that identify available versions of a specified table.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The database in the catalog in which the table resides. For Hive compatibility, this name is entirely lowercase.
        table_name(str): The name of the table. For Hive compatibility, this name is entirely lowercase.
        next_token(str, optional): A continuation token, if this is not the first call. Defaults to None.
        max_results(int, optional): The maximum number of table versions to return in one response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.table.version.get_all(
                ctx, database_name=value, table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.table.version.get_all database_name=value, table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_table_versions",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableName": table_name,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> None:
    r"""
    **Autogenerated function**

    Adds or updates tags for a resource in AWS CodeCommit. For a list of valid resources in AWS CodeCommit, see CodeCommit Resources and Operations in the AWS CodeCommit User Guide.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource to which you want to add or update tags.
        tags(Dict): The key-value pair to use when tagging this repository.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes tags for a resource in AWS CodeCommit. For a list of valid resources in AWS CodeCommit, see CodeCommit Resources and Operations in the AWS CodeCommit User Guide.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource to which you want to remove tags.
        tag_keys(List): The tag key for each tag that you want to remove from the resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def write(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    records: List,
    common_attributes: Dict = None,
) -> None:
    r"""
    **Autogenerated function**

    The WriteRecords operation enables you to write your time series data into Timestream. You can specify a single data point or a batch of data points to be inserted into the system. Timestream offers you with a flexible schema that auto detects the column names and data types for your Timestream tables based on the dimension names and data types of the data points you specify when invoking writes into the database. Timestream support eventual consistency read semantics. This means that when you query data immediately after writing a batch of data into Timestream, the query results might not reflect the results of a recently completed write operation. The results may also include some stale data. If you repeat the query request after a short time, the results should return the latest data. Service quotas apply. For more information, see Access Management in the Timestream Developer Guide.

    Args:
        database_name(str): The name of the Timestream database.
        table_name(str): The name of the Timesream table.
        common_attributes(Dict, optional): A record containing the common measure and dimension attributes shared across all the records in the request. The measure and dimension attributes specified in here will be merged with the measure and dimension attributes in the records object when the data is written into Timestream. . Defaults to None.
        records(List): An array of records containing the unique dimension and measure attributes for each time series data point. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_write.record.write(
                ctx, database_name=value, table_name=value, records=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_write.record.write database_name=value, table_name=value, records=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-write",
        operation="write_records",
        op_kwargs={
            "DatabaseName": database_name,
            "TableName": table_name,
            "CommonAttributes": common_attributes,
            "Records": records,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def reset(hub, ctx, account_id: str, user_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Resets the personal meeting PIN for the specified user on an Amazon Chime account. Returns the User object with the updated personal meeting PIN.

    Args:
        account_id(str): The Amazon Chime account ID.
        user_id(str): The user ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.personal_pin.reset(ctx, account_id=value, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.personal_pin.reset account_id=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="reset_personal_pin",
        op_kwargs={"AccountId": account_id, "UserId": user_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    logger_definition_id: str,
    amzn_client_token: str = None,
    loggers: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a version of a logger definition that has already been defined.

    Args:
        amzn_client_token(str, optional): A client token used to correlate requests and responses. Defaults to None.
        logger_definition_id(str): The ID of the logger definition.
        loggers(List, optional): A list of loggers. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.logger_definition.version.create(
                ctx, logger_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.logger_definition.version.create logger_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="create_logger_definition_version",
        op_kwargs={
            "AmznClientToken": amzn_client_token,
            "LoggerDefinitionId": logger_definition_id,
            "Loggers": loggers,
        },
    )


async def get(
    hub,
    ctx,
    logger_definition_id: str,
    logger_definition_version_id: str,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a logger definition version.

    Args:
        logger_definition_id(str): The ID of the logger definition.
        logger_definition_version_id(str): The ID of the logger definition version. This value maps to the ''Version'' property of the corresponding ''VersionInformation'' object, which is returned by ''ListLoggerDefinitionVersions'' requests. If the version is the last one that was associated with a logger definition, the value also maps to the ''LatestVersion'' property of the corresponding ''DefinitionInformation'' object.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.logger_definition.version.get(
                ctx, logger_definition_id=value, logger_definition_version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.logger_definition.version.get logger_definition_id=value, logger_definition_version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_logger_definition_version",
        op_kwargs={
            "LoggerDefinitionId": logger_definition_id,
            "LoggerDefinitionVersionId": logger_definition_version_id,
            "NextToken": next_token,
        },
    )


async def list_all(
    hub, ctx, logger_definition_id: str, max_results: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the versions of a logger definition.

    Args:
        logger_definition_id(str): The ID of the logger definition.
        max_results(str, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.logger_definition.version.list_all(
                ctx, logger_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.logger_definition.version.list_all logger_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="list_logger_definition_versions",
        op_kwargs={
            "LoggerDefinitionId": logger_definition_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    description: str,
    group_name: str,
    vpc_id: str = None,
    tag_specifications: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a security group. A security group acts as a virtual firewall for your instance to control inbound and outbound traffic. For more information, see Amazon EC2 Security Groups in the Amazon Elastic Compute Cloud User Guide and Security Groups for Your VPC in the Amazon Virtual Private Cloud User Guide. When you create a security group, you specify a friendly name of your choice. You can have a security group for use in EC2-Classic with the same name as a security group for use in a VPC. However, you can't have two security groups for use in EC2-Classic with the same name or two security groups for use in a VPC with the same name. You have a default security group for use in EC2-Classic and a default security group for use in your VPC. If you don't specify a security group when you launch an instance, the instance is launched into the appropriate default security group. A default security group includes a default rule that grants instances unrestricted network access to each other. You can add or remove rules from your security groups using AuthorizeSecurityGroupIngress, AuthorizeSecurityGroupEgress, RevokeSecurityGroupIngress, and RevokeSecurityGroupEgress. For more information about VPC security group limits, see Amazon VPC Limits.

    Args:
        description(str): A description for the security group. This is informational only. Constraints: Up to 255 characters in length Constraints for EC2-Classic: ASCII characters Constraints for EC2-VPC: a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=&;{}!$*.
        group_name(str): The name of the security group. Constraints: Up to 255 characters in length. Cannot start with sg-. Constraints for EC2-Classic: ASCII characters Constraints for EC2-VPC: a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=&;{}!$*.
        vpc_id(str, optional): [EC2-VPC] The ID of the VPC. Required for EC2-VPC. Defaults to None.
        tag_specifications(List, optional): The tags to assign to the security group. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.security_group.init.create(
                ctx, description=value, group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.security_group.init.create description=value, group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_security_group",
        op_kwargs={
            "Description": description,
            "GroupName": group_name,
            "VpcId": vpc_id,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub, ctx, group_id: str = None, group_name: str = None, dry_run: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes a security group. If you attempt to delete a security group that is associated with an instance, or is referenced by another security group, the operation fails with InvalidGroup.InUse in EC2-Classic or DependencyViolation in EC2-VPC.

    Args:
        group_id(str, optional): The ID of the security group. Required for a nondefault VPC. Defaults to None.
        group_name(str, optional): [EC2-Classic, default VPC] The name of the security group. You can specify either the security group name or the security group ID. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.security_group.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.security_group.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_security_group",
        op_kwargs={"GroupId": group_id, "GroupName": group_name, "DryRun": dry_run},
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    group_ids: List = None,
    group_names: List = None,
    dry_run: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified security groups or all of your security groups. A security group is for use with instances either in the EC2-Classic platform or in a specific VPC. For more information, see Amazon EC2 Security Groups in the Amazon Elastic Compute Cloud User Guide and Security Groups for Your VPC in the Amazon Virtual Private Cloud User Guide.

    Args:
        filters(List, optional): The filters. If using multiple filters for rules, the results include security groups for which any combination of rules - not necessarily a single rule - match all filters.    description - The description of the security group.    egress.ip-permission.cidr - An IPv4 CIDR block for an outbound security group rule.    egress.ip-permission.from-port - For an outbound rule, the start of port range for the TCP and UDP protocols, or an ICMP type number.    egress.ip-permission.group-id - The ID of a security group that has been referenced in an outbound security group rule.    egress.ip-permission.group-name - The name of a security group that is referenced in an outbound security group rule.    egress.ip-permission.ipv6-cidr - An IPv6 CIDR block for an outbound security group rule.    egress.ip-permission.prefix-list-id - The ID of a prefix list to which a security group rule allows outbound access.    egress.ip-permission.protocol - The IP protocol for an outbound security group rule (tcp | udp | icmp, a protocol number, or -1 for all protocols).    egress.ip-permission.to-port - For an outbound rule, the end of port range for the TCP and UDP protocols, or an ICMP code.    egress.ip-permission.user-id - The ID of an Amazon Web Services account that has been referenced in an outbound security group rule.    group-id - The ID of the security group.     group-name - The name of the security group.    ip-permission.cidr - An IPv4 CIDR block for an inbound security group rule.    ip-permission.from-port - For an inbound rule, the start of port range for the TCP and UDP protocols, or an ICMP type number.    ip-permission.group-id - The ID of a security group that has been referenced in an inbound security group rule.    ip-permission.group-name - The name of a security group that is referenced in an inbound security group rule.    ip-permission.ipv6-cidr - An IPv6 CIDR block for an inbound security group rule.    ip-permission.prefix-list-id - The ID of a prefix list from which a security group rule allows inbound access.    ip-permission.protocol - The IP protocol for an inbound security group rule (tcp | udp | icmp, a protocol number, or -1 for all protocols).    ip-permission.to-port - For an inbound rule, the end of port range for the TCP and UDP protocols, or an ICMP code.    ip-permission.user-id - The ID of an Amazon Web Services account that has been referenced in an inbound security group rule.    owner-id - The Amazon Web Services account ID of the owner of the security group.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC specified when the security group was created.  . Defaults to None.
        group_ids(List, optional): The IDs of the security groups. Required for security groups in a nondefault VPC. Default: Describes all of your security groups. Defaults to None.
        group_names(List, optional): [EC2-Classic and default VPC only] The names of the security groups. You can specify either the security group name or the security group ID. For security groups in a nondefault VPC, use the group-name filter to describe security groups by name. Default: Describes all of your security groups. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another request with the returned NextToken value. This value can be between 5 and 1000. If this parameter is not specified, then all results are returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.security_group.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.security_group.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_security_groups",
        op_kwargs={
            "Filters": filters,
            "GroupIds": group_ids,
            "GroupNames": group_names,
            "DryRun": dry_run,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    statement_name: str,
    work_group: str,
    query_statement: str,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a prepared statement for use with SQL queries in Athena.

    Args:
        statement_name(str): The name of the prepared statement.
        work_group(str): The name of the workgroup to which the prepared statement belongs.
        query_statement(str): The query string for the prepared statement.
        description(str, optional): The description of the prepared statement. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.prepared_statement.create(
                ctx, statement_name=value, work_group=value, query_statement=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.prepared_statement.create statement_name=value, work_group=value, query_statement=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="create_prepared_statement",
        op_kwargs={
            "StatementName": statement_name,
            "WorkGroup": work_group,
            "QueryStatement": query_statement,
            "Description": description,
        },
    )


async def delete(hub, ctx, statement_name: str, work_group: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the prepared statement with the specified name from the specified workgroup.

    Args:
        statement_name(str): The name of the prepared statement to delete.
        work_group(str): The workgroup to which the statement to be deleted belongs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.prepared_statement.delete(
                ctx, statement_name=value, work_group=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.prepared_statement.delete statement_name=value, work_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="delete_prepared_statement",
        op_kwargs={"StatementName": statement_name, "WorkGroup": work_group},
    )


async def get(hub, ctx, statement_name: str, work_group: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the prepared statement with the specified name from the specified workgroup.

    Args:
        statement_name(str): The name of the prepared statement to retrieve.
        work_group(str): The workgroup to which the statement to be retrieved belongs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.prepared_statement.get(
                ctx, statement_name=value, work_group=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.prepared_statement.get statement_name=value, work_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="get_prepared_statement",
        op_kwargs={"StatementName": statement_name, "WorkGroup": work_group},
    )


async def list_all(
    hub, ctx, work_group: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the prepared statements in the specfied workgroup.

    Args:
        work_group(str): The workgroup to list the prepared statements for.
        next_token(str, optional): A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.prepared_statement.list_all(ctx, work_group=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.prepared_statement.list_all work_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="list_prepared_statements",
        op_kwargs={
            "WorkGroup": work_group,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    statement_name: str,
    work_group: str,
    query_statement: str,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a prepared statement.

    Args:
        statement_name(str): The name of the prepared statement.
        work_group(str): The workgroup for the prepared statement.
        query_statement(str): The query string for the prepared statement.
        description(str, optional): The description of the prepared statement. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.prepared_statement.update(
                ctx, statement_name=value, work_group=value, query_statement=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.prepared_statement.update statement_name=value, work_group=value, query_statement=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="update_prepared_statement",
        op_kwargs={
            "StatementName": statement_name,
            "WorkGroup": work_group,
            "QueryStatement": query_statement,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(
    hub, ctx, vpc_id: str, vpn_gateway_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Attaches a virtual private gateway to a VPC. You can attach one virtual private gateway to one VPC at a time. For more information, see AWS Site-to-Site VPN in the AWS Site-to-Site VPN User Guide.

    Args:
        vpc_id(str): The ID of the VPC.
        vpn_gateway_id(str): The ID of the virtual private gateway.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpn.gateway.attach(ctx, vpc_id=value, vpn_gateway_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpn.gateway.attach vpc_id=value, vpn_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="attach_vpn_gateway",
        op_kwargs={"VpcId": vpc_id, "VpnGatewayId": vpn_gateway_id, "DryRun": dry_run},
    )


async def create(
    hub,
    ctx,
    type_: str,
    availability_zone: str = None,
    tag_specifications: List = None,
    amazon_side_asn: int = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a virtual private gateway. A virtual private gateway is the endpoint on the VPC side of your VPN connection. You can create a virtual private gateway before creating the VPC itself. For more information, see AWS Site-to-Site VPN in the AWS Site-to-Site VPN User Guide.

    Args:
        availability_zone(str, optional): The Availability Zone for the virtual private gateway. Defaults to None.
        type_(str): The type of VPN connection this virtual private gateway supports.
        tag_specifications(List, optional): The tags to apply to the virtual private gateway. Defaults to None.
        amazon_side_asn(int, optional): A private Autonomous System Number (ASN) for the Amazon side of a BGP session. If you're using a 16-bit ASN, it must be in the 64512 to 65534 range. If you're using a 32-bit ASN, it must be in the 4200000000 to 4294967294 range. Default: 64512. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpn.gateway.create(ctx, type_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpn.gateway.create type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_vpn_gateway",
        op_kwargs={
            "AvailabilityZone": availability_zone,
            "Type": type_,
            "TagSpecifications": tag_specifications,
            "AmazonSideAsn": amazon_side_asn,
            "DryRun": dry_run,
        },
    )


async def delete(hub, ctx, vpn_gateway_id: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified virtual private gateway. You must first detach the virtual private gateway from the VPC. Note that you don't need to delete the virtual private gateway if you plan to delete and recreate the VPN connection between your VPC and your network.

    Args:
        vpn_gateway_id(str): The ID of the virtual private gateway.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpn.gateway.delete(ctx, vpn_gateway_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpn.gateway.delete vpn_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_vpn_gateway",
        op_kwargs={"VpnGatewayId": vpn_gateway_id, "DryRun": dry_run},
    )


async def describe_all(
    hub, ctx, filters: List = None, vpn_gateway_ids: List = None, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your virtual private gateways. For more information, see AWS Site-to-Site VPN in the AWS Site-to-Site VPN User Guide.

    Args:
        filters(List, optional): One or more filters.    amazon-side-asn - The Autonomous System Number (ASN) for the Amazon side of the gateway.    attachment.state - The current state of the attachment between the gateway and the VPC (attaching | attached | detaching | detached).    attachment.vpc-id - The ID of an attached VPC.    availability-zone - The Availability Zone for the virtual private gateway (if applicable).    state - The state of the virtual private gateway (pending | available | deleting | deleted).    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    type - The type of virtual private gateway. Currently the only supported type is ipsec.1.    vpn-gateway-id - The ID of the virtual private gateway.  . Defaults to None.
        vpn_gateway_ids(List, optional): One or more virtual private gateway IDs. Default: Describes all your virtual private gateways. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpn.gateway.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpn.gateway.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_vpn_gateways",
        op_kwargs={
            "Filters": filters,
            "VpnGatewayIds": vpn_gateway_ids,
            "DryRun": dry_run,
        },
    )


async def detach(
    hub, ctx, vpc_id: str, vpn_gateway_id: str, dry_run: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Detaches a virtual private gateway from a VPC. You do this if you're planning to turn off the VPC and not use it anymore. You can confirm a virtual private gateway has been completely detached from a VPC by describing the virtual private gateway (any attachments to the virtual private gateway are also described). You must wait for the attachment's state to switch to detached before you can delete the VPC or attach a different VPC to the virtual private gateway.

    Args:
        vpc_id(str): The ID of the VPC.
        vpn_gateway_id(str): The ID of the virtual private gateway.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpn.gateway.detach(ctx, vpc_id=value, vpn_gateway_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpn.gateway.detach vpc_id=value, vpn_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="detach_vpn_gateway",
        op_kwargs={"VpcId": vpc_id, "VpnGatewayId": vpn_gateway_id, "DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub,
    ctx,
    configuration_id: str,
    port_information_needed: bool = None,
    neighbor_configuration_ids: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of servers that are one network hop away from a specified server.

    Args:
        configuration_id(str): Configuration ID of the server for which neighbors are being listed.
        port_information_needed(bool, optional): Flag to indicate if port and protocol information is needed as part of the response. Defaults to None.
        neighbor_configuration_ids(List, optional): List of configuration IDs to test for one-hop-away. Defaults to None.
        max_results(int, optional): Maximum number of results to return in a single page of output. Defaults to None.
        next_token(str, optional): Token to retrieve the next set of results. For example, if you previously specified 100 IDs for ListServerNeighborsRequest$neighborConfigurationIds but set ListServerNeighborsRequest$maxResults to 10, you received a set of 10 results along with a token. Use that token in this query to get the next set of 10. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.server_neighbor.list_all(ctx, configuration_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.server_neighbor.list_all configuration_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="list_server_neighbors",
        op_kwargs={
            "configurationId": configuration_id,
            "portInformationNeeded": port_information_needed,
            "neighborConfigurationIds": neighbor_configuration_ids,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    organization_conformance_pack_names: List = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides organization conformance pack deployment status for an organization.   The status is not considered successful until organization conformance pack is successfully deployed in all the member accounts with an exception of excluded accounts. When you specify the limit and the next token, you receive a paginated response. Limit and next token are not applicable if you specify organization conformance pack names. They are only applicable, when you request all the organization conformance packs.

    Args:
        organization_conformance_pack_names(List, optional): The names of organization conformance packs for which you want status details. If you do not specify any names, AWS Config returns details for all your organization conformance packs. . Defaults to None.
        limit(int, optional): The maximum number of OrganizationConformancePackStatuses returned on each page. If you do no specify a number, AWS Config uses the default. The default is 100. . Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.organization.conformance_pack.status.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.organization.conformance_pack.status.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_organization_conformance_pack_statuses",
        op_kwargs={
            "OrganizationConformancePackNames": organization_conformance_pack_names,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    resource_definition_id: str,
    amzn_client_token: str = None,
    resources: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a version of a resource definition that has already been defined.

    Args:
        amzn_client_token(str, optional): A client token used to correlate requests and responses. Defaults to None.
        resource_definition_id(str): The ID of the resource definition.
        resources(List, optional): A list of resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.resource.definition.version.create(
                ctx, resource_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.resource.definition.version.create resource_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="create_resource_definition_version",
        op_kwargs={
            "AmznClientToken": amzn_client_token,
            "ResourceDefinitionId": resource_definition_id,
            "Resources": resources,
        },
    )


async def get(
    hub, ctx, resource_definition_id: str, resource_definition_version_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a resource definition version, including which resources are included in the version.

    Args:
        resource_definition_id(str): The ID of the resource definition.
        resource_definition_version_id(str): The ID of the resource definition version. This value maps to the ''Version'' property of the corresponding ''VersionInformation'' object, which is returned by ''ListResourceDefinitionVersions'' requests. If the version is the last one that was associated with a resource definition, the value also maps to the ''LatestVersion'' property of the corresponding ''DefinitionInformation'' object.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.resource.definition.version.get(
                ctx, resource_definition_id=value, resource_definition_version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.resource.definition.version.get resource_definition_id=value, resource_definition_version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_resource_definition_version",
        op_kwargs={
            "ResourceDefinitionId": resource_definition_id,
            "ResourceDefinitionVersionId": resource_definition_version_id,
        },
    )


async def list_all(
    hub,
    ctx,
    resource_definition_id: str,
    max_results: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the versions of a resource definition.

    Args:
        max_results(str, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.
        resource_definition_id(str): The ID of the resource definition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.resource.definition.version.list_all(
                ctx, resource_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.resource.definition.version.list_all resource_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="list_resource_definition_versions",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "ResourceDefinitionId": resource_definition_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub, ctx, attribute: str, instance_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified attribute of the specified instance. You can specify only one attribute at a time. Valid attribute values are: instanceType | kernel | ramdisk | userData | disableApiTermination | instanceInitiatedShutdownBehavior | rootDeviceName | blockDeviceMapping | productCodes | sourceDestCheck | groupSet | ebsOptimized | sriovNetSupport

    Args:
        attribute(str): The instance attribute. Note: The enaSupport attribute is not supported at this time.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_id(str): The ID of the instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.attribute.describe(
                ctx, attribute=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.attribute.describe attribute=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_instance_attribute",
        op_kwargs={
            "Attribute": attribute,
            "DryRun": dry_run,
            "InstanceId": instance_id,
        },
    )


async def modify(
    hub,
    ctx,
    instance_id: str,
    source_dest_check: Dict = None,
    attribute: str = None,
    block_device_mappings: List = None,
    disable_api_termination: Dict = None,
    dry_run: bool = None,
    ebs_optimized: Dict = None,
    ena_support: Dict = None,
    groups: List = None,
    instance_initiated_shutdown_behavior: Dict = None,
    instance_type: Dict = None,
    kernel: Dict = None,
    ramdisk: Dict = None,
    sriov_net_support: Dict = None,
    user_data: Dict = None,
    value: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Modifies the specified attribute of the specified instance. You can specify only one attribute at a time.  Note: Using this action to change the security groups associated with an elastic network interface (ENI) attached to an instance in a VPC can result in an error if the instance has more than one ENI. To change the security groups associated with an ENI attached to an instance that has multiple ENIs, we recommend that you use the ModifyNetworkInterfaceAttribute action. To modify some attributes, the instance must be stopped. For more information, see Modifying attributes of a stopped instance in the Amazon EC2 User Guide.

    Args:
        source_dest_check(Dict, optional): Enable or disable source/destination checks, which ensure that the instance is either the source or the destination of any traffic that it receives. If the value is true, source/destination checks are enabled; otherwise, they are disabled. The default value is true. You must disable source/destination checks if the instance runs services such as network address translation, routing, or firewalls. Defaults to None.
        attribute(str, optional): The name of the attribute. Defaults to None.
        block_device_mappings(List, optional): Modifies the DeleteOnTermination attribute for volumes that are currently attached. The volume must be owned by the caller. If no value is specified for DeleteOnTermination, the default is true and the volume is deleted when the instance is terminated. To add instance store volumes to an Amazon EBS-backed instance, you must add them when you launch the instance. For more information, see Updating the block device mapping when launching an instance in the Amazon EC2 User Guide. Defaults to None.
        disable_api_termination(Dict, optional): If the value is true, you can't terminate the instance using the Amazon EC2 console, CLI, or API; otherwise, you can. You cannot use this parameter for Spot Instances. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        ebs_optimized(Dict, optional): Specifies whether the instance is optimized for Amazon EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS Optimized instance. Defaults to None.
        ena_support(Dict, optional): Set to true to enable enhanced networking with ENA for the instance. This option is supported only for HVM instances. Specifying this option with a PV instance can make it unreachable. Defaults to None.
        groups(List, optional): [EC2-VPC] Replaces the security groups of the instance with the specified security groups. You must specify at least one security group, even if it's just the default security group for the VPC. You must specify the security group ID, not the security group name. Defaults to None.
        instance_id(str): The ID of the instance.
        instance_initiated_shutdown_behavior(Dict, optional): Specifies whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown). Defaults to None.
        instance_type(Dict, optional): Changes the instance type to the specified value. For more information, see Instance types in the Amazon EC2 User Guide. If the instance type is not valid, the error returned is InvalidInstanceAttributeValue. Defaults to None.
        kernel(Dict, optional): Changes the instance's kernel to the specified value. We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see PV-GRUB. Defaults to None.
        ramdisk(Dict, optional): Changes the instance's RAM disk to the specified value. We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see PV-GRUB. Defaults to None.
        sriov_net_support(Dict, optional): Set to simple to enable enhanced networking with the Intel 82599 Virtual Function interface for the instance. There is no way to disable enhanced networking with the Intel 82599 Virtual Function interface at this time. This option is supported only for HVM instances. Specifying this option with a PV instance can make it unreachable. Defaults to None.
        user_data(Dict, optional): Changes the instance's user data to the specified value. If you are using an Amazon Web Services SDK or command line tool, base64-encoding is performed for you, and you can load the text from a file. Otherwise, you must provide base64-encoded text. Defaults to None.
        value(str, optional): A new value for the attribute. Use only with the kernel, ramdisk, userData, disableApiTermination, or instanceInitiatedShutdownBehavior attribute. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.attribute.modify(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.attribute.modify instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_instance_attribute",
        op_kwargs={
            "SourceDestCheck": source_dest_check,
            "Attribute": attribute,
            "BlockDeviceMappings": block_device_mappings,
            "DisableApiTermination": disable_api_termination,
            "DryRun": dry_run,
            "EbsOptimized": ebs_optimized,
            "EnaSupport": ena_support,
            "Groups": groups,
            "InstanceId": instance_id,
            "InstanceInitiatedShutdownBehavior": instance_initiated_shutdown_behavior,
            "InstanceType": instance_type,
            "Kernel": kernel,
            "Ramdisk": ramdisk,
            "SriovNetSupport": sriov_net_support,
            "UserData": user_data,
            "Value": value,
        },
    )


async def reset(
    hub, ctx, attribute: str, instance_id: str, dry_run: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Resets an attribute of an instance to its default value. To reset the kernel or ramdisk, the instance must be in a stopped state. To reset the sourceDestCheck, the instance can be either running or stopped. The sourceDestCheck attribute controls whether source/destination checking is enabled. The default value is true, which means checking is enabled. This value must be false for a NAT instance to perform NAT. For more information, see NAT Instances in the Amazon VPC User Guide.

    Args:
        attribute(str): The attribute to reset.  You can only reset the following attributes: kernel | ramdisk | sourceDestCheck. To change an instance attribute, use ModifyInstanceAttribute. .
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_id(str): The ID of the instance.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.attribute.reset(
                ctx, attribute=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.attribute.reset attribute=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="reset_instance_attribute",
        op_kwargs={
            "Attribute": attribute,
            "DryRun": dry_run,
            "InstanceId": instance_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    app_id: str,
    environment_name: str,
    stack_name: str = None,
    deployment_artifacts: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a new backend environment for an Amplify app.

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        environment_name(str):  The name for the backend environment. .
        stack_name(str, optional):  The AWS CloudFormation stack name of a backend environment. . Defaults to None.
        deployment_artifacts(str, optional):  The name of deployment artifacts. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.backend_environment.create(
                ctx, app_id=value, environment_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.backend_environment.create app_id=value, environment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="create_backend_environment",
        op_kwargs={
            "appId": app_id,
            "environmentName": environment_name,
            "stackName": stack_name,
            "deploymentArtifacts": deployment_artifacts,
        },
    )


async def delete(hub, ctx, app_id: str, environment_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a backend environment for an Amplify app.

    Args:
        app_id(str):  The unique ID of an Amplify app. .
        environment_name(str):  The name of a backend environment of an Amplify app. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.backend_environment.delete(
                ctx, app_id=value, environment_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.backend_environment.delete app_id=value, environment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="delete_backend_environment",
        op_kwargs={"appId": app_id, "environmentName": environment_name},
    )


async def get(hub, ctx, app_id: str, environment_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns a backend environment for an Amplify app.

    Args:
        app_id(str):  The unique id for an Amplify app. .
        environment_name(str):  The name for the backend environment. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.backend_environment.get(
                ctx, app_id=value, environment_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.backend_environment.get app_id=value, environment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="get_backend_environment",
        op_kwargs={"appId": app_id, "environmentName": environment_name},
    )


async def list_all(
    hub,
    ctx,
    app_id: str,
    environment_name: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Lists the backend environments for an Amplify app.

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        environment_name(str, optional):  The name of the backend environment . Defaults to None.
        next_token(str, optional):  A pagination token. Set to null to start listing backend environments from the start. If a non-null pagination token is returned in a result, pass its value in here to list more backend environments. . Defaults to None.
        max_results(int, optional):  The maximum number of records to list in a single response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.backend_environment.list_all(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.backend_environment.list_all app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="list_backend_environments",
        op_kwargs={
            "appId": app_id,
            "environmentName": environment_name,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "with_hit_type"


async def create(
    hub,
    ctx,
    hit_type_id: str,
    lifetime_in_seconds: int,
    max_assignments: int = None,
    question: str = None,
    requester_annotation: str = None,
    unique_request_token: str = None,
    assignment_review_policy: Dict = None,
    hit_review_policy: Dict = None,
    hit_layout_id: str = None,
    hit_layout_parameters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The CreateHITWithHITType operation creates a new Human Intelligence Task (HIT) using an existing HITTypeID generated by the CreateHITType operation.   This is an alternative way to create HITs from the CreateHIT operation. This is the recommended best practice for Requesters who are creating large numbers of HITs.  CreateHITWithHITType also supports several ways to provide question data: by providing a value for the Question parameter that fully specifies the contents of the HIT, or by providing a HitLayoutId and associated HitLayoutParameters.    If a HIT is created with 10 or more maximum assignments, there is an additional fee. For more information, see Amazon Mechanical Turk Pricing.

    Args:
        hit_type_id(str): The HIT type ID you want to create this HIT with.
        max_assignments(int, optional):  The number of times the HIT can be accepted and completed before the HIT becomes unavailable. . Defaults to None.
        lifetime_in_seconds(int):  An amount of time, in seconds, after which the HIT is no longer available for users to accept. After the lifetime of the HIT elapses, the HIT no longer appears in HIT searches, even if not all of the assignments for the HIT have been accepted. .
        question(str, optional):  The data the person completing the HIT uses to produce the results.   Constraints: Must be a QuestionForm data structure, an ExternalQuestion data structure, or an HTMLQuestion data structure. The XML question data must not be larger than 64 kilobytes (65,535 bytes) in size, including whitespace.  Either a Question parameter or a HITLayoutId parameter must be provided. Defaults to None.
        requester_annotation(str, optional):  An arbitrary data field. The RequesterAnnotation parameter lets your application attach arbitrary data to the HIT for tracking purposes. For example, this parameter could be an identifier internal to the Requester's application that corresponds with the HIT.   The RequesterAnnotation parameter for a HIT is only visible to the Requester who created the HIT. It is not shown to the Worker, or any other Requester.   The RequesterAnnotation parameter may be different for each HIT you submit. It does not affect how your HITs are grouped. . Defaults to None.
        unique_request_token(str, optional):  A unique identifier for this request which allows you to retry the call on error without creating duplicate HITs. This is useful in cases such as network timeouts where it is unclear whether or not the call succeeded on the server. If the HIT already exists in the system from a previous call using the same UniqueRequestToken, subsequent calls will return a AWS.MechanicalTurk.HitAlreadyExists error with a message containing the HITId.    Note: It is your responsibility to ensure uniqueness of the token. The unique token expires after 24 hours. Subsequent calls using the same UniqueRequestToken made after the 24 hour limit could create duplicate HITs.  . Defaults to None.
        assignment_review_policy(Dict, optional):  The Assignment-level Review Policy applies to the assignments under the HIT. You can specify for Mechanical Turk to take various actions based on the policy. . Defaults to None.
        hit_review_policy(Dict, optional):  The HIT-level Review Policy applies to the HIT. You can specify for Mechanical Turk to take various actions based on the policy. . Defaults to None.
        hit_layout_id(str, optional):  The HITLayoutId allows you to use a pre-existing HIT design with placeholder values and create an additional HIT by providing those values as HITLayoutParameters.   Constraints: Either a Question parameter or a HITLayoutId parameter must be provided. . Defaults to None.
        hit_layout_parameters(List, optional):  If the HITLayoutId is provided, any placeholder values must be filled in with values using the HITLayoutParameter structure. For more information, see HITLayout. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.hit.with_hit_type_.create(
                ctx, hit_type_id=value, lifetime_in_seconds=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.hit.with_hit_type.create hit_type_id=value, lifetime_in_seconds=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="create_hit_with_hit_type",
        op_kwargs={
            "HITTypeId": hit_type_id,
            "MaxAssignments": max_assignments,
            "LifetimeInSeconds": lifetime_in_seconds,
            "Question": question,
            "RequesterAnnotation": requester_annotation,
            "UniqueRequestToken": unique_request_token,
            "AssignmentReviewPolicy": assignment_review_policy,
            "HITReviewPolicy": hit_review_policy,
            "HITLayoutId": hit_layout_id,
            "HITLayoutParameters": hit_layout_parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    log_group_name: str = None,
    status: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of CloudWatch Logs Insights queries that are scheduled, executing, or have been executed recently in this account. You can request all queries or limit it to queries of a specific log group or queries with a certain status.

    Args:
        log_group_name(str, optional): Limits the returned queries to only those for the specified log group. Defaults to None.
        status(str, optional): Limits the returned queries to only those that have the specified status. Valid values are Cancelled, Complete, Failed, Running, and Scheduled. Defaults to None.
        max_results(int, optional): Limits the number of returned queries to the specified number. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. The token expires after 24 hours. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.query.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.query.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="describe_queries",
        op_kwargs={
            "logGroupName": log_group_name,
            "status": status,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def start(
    hub,
    ctx,
    start_time: int,
    end_time: int,
    query_string: str,
    log_group_name: str = None,
    log_group_names: List = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Schedules a query of a log group using CloudWatch Logs Insights. You specify the log group and time range to query and the query string to use. For more information, see CloudWatch Logs Insights Query Syntax. Queries time out after 15 minutes of execution. If your queries are timing out, reduce the time range being searched or partition your query into a number of queries.

    Args:
        log_group_name(str, optional): The log group on which to perform the query. A StartQuery operation must include a logGroupNames or a logGroupName parameter, but not both. Defaults to None.
        log_group_names(List, optional): The list of log groups to be queried. You can include up to 20 log groups. A StartQuery operation must include a logGroupNames or a logGroupName parameter, but not both. Defaults to None.
        start_time(int): The beginning of the time range to query. The range is inclusive, so the specified start time is included in the query. Specified as epoch time, the number of seconds since January 1, 1970, 00:00:00 UTC.
        end_time(int): The end of the time range to query. The range is inclusive, so the specified end time is included in the query. Specified as epoch time, the number of seconds since January 1, 1970, 00:00:00 UTC.
        query_string(str): The query string to use. For more information, see CloudWatch Logs Insights Query Syntax.
        limit(int, optional): The maximum number of log events to return in the query. If the query string uses the fields command, only the specified fields and their values are returned. The default is 1000. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.query.init.start(
                ctx, start_time=value, end_time=value, query_string=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.query.init.start start_time=value, end_time=value, query_string=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="start_query",
        op_kwargs={
            "logGroupName": log_group_name,
            "logGroupNames": log_group_names,
            "startTime": start_time,
            "endTime": end_time,
            "queryString": query_string,
            "limit": limit,
        },
    )


async def stop(hub, ctx, query_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a CloudWatch Logs Insights query that is in progress. If the query has already ended, the operation returns an error indicating that the specified query is not running.

    Args:
        query_id(str): The ID number of the query to stop. To find this ID number, use DescribeQueries.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.query.init.stop(ctx, query_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.query.init.stop query_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="stop_query",
        op_kwargs={"queryId": query_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub,
    ctx,
    source_db_cluster_parameter_group_identifier: str,
    target_db_cluster_parameter_group_identifier: str,
    target_db_cluster_parameter_group_description: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies the specified cluster parameter group.

    Args:
        source_db_cluster_parameter_group_identifier(str): The identifier or Amazon Resource Name (ARN) for the source cluster parameter group. Constraints:   Must specify a valid cluster parameter group.   If the source cluster parameter group is in the same Region as the copy, specify a valid parameter group identifier; for example, my-db-cluster-param-group, or a valid ARN.   If the source parameter group is in a different Region than the copy, specify a valid cluster parameter group ARN; for example, arn:aws:rds:us-east-1:123456789012:sample-cluster:sample-parameter-group.  .
        target_db_cluster_parameter_group_identifier(str): The identifier for the copied cluster parameter group. Constraints:   Cannot be null, empty, or blank.   Must contain from 1 to 255 letters, numbers, or hyphens.    The first character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.    Example: my-cluster-param-group1 .
        target_db_cluster_parameter_group_description(str): A description for the copied cluster parameter group.
        tags(List, optional): The tags that are to be assigned to the parameter group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.parameter.group.copy(
                ctx,
                source_db_cluster_parameter_group_identifier=value,
                target_db_cluster_parameter_group_identifier=value,
                target_db_cluster_parameter_group_description=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.parameter.group.copy source_db_cluster_parameter_group_identifier=value, target_db_cluster_parameter_group_identifier=value, target_db_cluster_parameter_group_description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="copy_db_cluster_parameter_group",
        op_kwargs={
            "SourceDBClusterParameterGroupIdentifier": source_db_cluster_parameter_group_identifier,
            "TargetDBClusterParameterGroupIdentifier": target_db_cluster_parameter_group_identifier,
            "TargetDBClusterParameterGroupDescription": target_db_cluster_parameter_group_description,
            "Tags": tags,
        },
    )


async def create(
    hub,
    ctx,
    db_cluster_parameter_group_name: str,
    db_parameter_group_family: str,
    description: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new cluster parameter group. Parameters in a cluster parameter group apply to all of the instances in a cluster. A cluster parameter group is initially created with the default parameters for the database engine used by instances in the cluster. In Amazon DocumentDB, you cannot make modifications directly to the default.docdb3.6 cluster parameter group. If your Amazon DocumentDB cluster is using the default cluster parameter group and you want to modify a value in it, you must first  create a new parameter group or  copy an existing parameter group, modify it, and then apply the modified parameter group to your cluster. For the new cluster parameter group and associated settings to take effect, you must then reboot the instances in the cluster without failover. For more information, see  Modifying Amazon DocumentDB Cluster Parameter Groups.

    Args:
        db_cluster_parameter_group_name(str): The name of the cluster parameter group. Constraints:   Must not match the name of an existing DBClusterParameterGroup.    This value is stored as a lowercase string. .
        db_parameter_group_family(str): The cluster parameter group family name.
        description(str): The description for the cluster parameter group.
        tags(List, optional): The tags to be assigned to the cluster parameter group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.parameter.group.create(
                ctx,
                db_cluster_parameter_group_name=value,
                db_parameter_group_family=value,
                description=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.parameter.group.create db_cluster_parameter_group_name=value, db_parameter_group_family=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="create_db_cluster_parameter_group",
        op_kwargs={
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "DBParameterGroupFamily": db_parameter_group_family,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, db_cluster_parameter_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a specified cluster parameter group. The cluster parameter group to be deleted can't be associated with any clusters.

    Args:
        db_cluster_parameter_group_name(str): The name of the cluster parameter group. Constraints:   Must be the name of an existing cluster parameter group.   You can't delete a default cluster parameter group.   Cannot be associated with any clusters.  .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.parameter.group.delete(
                ctx, db_cluster_parameter_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.parameter.group.delete db_cluster_parameter_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="delete_db_cluster_parameter_group",
        op_kwargs={"DBClusterParameterGroupName": db_cluster_parameter_group_name},
    )


async def describe_all(
    hub,
    ctx,
    db_cluster_parameter_group_name: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of DBClusterParameterGroup descriptions. If a DBClusterParameterGroupName parameter is specified, the list contains only the description of the specified cluster parameter group.

    Args:
        db_cluster_parameter_group_name(str, optional): The name of a specific cluster parameter group to return details for. Constraints:   If provided, must match the name of an existing DBClusterParameterGroup.  . Defaults to None.
        filters(List, optional): This parameter is not currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.parameter.group.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.parameter.group.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="describe_db_cluster_parameter_groups",
        op_kwargs={
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def modify(
    hub, ctx, db_cluster_parameter_group_name: str, parameters: List
) -> Dict:
    r"""
    **Autogenerated function**

     Modifies the parameters of a cluster parameter group. To modify more than one parameter, submit a list of the following: ParameterName, ParameterValue, and ApplyMethod. A maximum of 20 parameters can be modified in a single request.   Changes to dynamic parameters are applied immediately. Changes to static parameters require a reboot or maintenance window before the change can take effect.   After you create a cluster parameter group, you should wait at least 5 minutes before creating your first cluster that uses that cluster parameter group as the default parameter group. This allows Amazon DocumentDB to fully complete the create action before the parameter group is used as the default for a new cluster. This step is especially important for parameters that are critical when creating the default database for a cluster, such as the character set for the default database defined by the character_set_database parameter.

    Args:
        db_cluster_parameter_group_name(str): The name of the cluster parameter group to modify.
        parameters(List): A list of parameters in the cluster parameter group to modify.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.parameter.group.modify(
                ctx, db_cluster_parameter_group_name=value, parameters=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.parameter.group.modify db_cluster_parameter_group_name=value, parameters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="modify_db_cluster_parameter_group",
        op_kwargs={
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "Parameters": parameters,
        },
    )


async def reset(
    hub,
    ctx,
    db_cluster_parameter_group_name: str,
    reset_all_parameters: bool = None,
    parameters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Modifies the parameters of a cluster parameter group to the default value. To reset specific parameters, submit a list of the following: ParameterName and ApplyMethod. To reset the entire cluster parameter group, specify the DBClusterParameterGroupName and ResetAllParameters parameters.   When you reset the entire group, dynamic parameters are updated immediately and static parameters are set to pending-reboot to take effect on the next DB instance reboot.

    Args:
        db_cluster_parameter_group_name(str): The name of the cluster parameter group to reset.
        reset_all_parameters(bool, optional): A value that is set to true to reset all parameters in the cluster parameter group to their default values, and false otherwise. You can't use this parameter if there is a list of parameter names specified for the Parameters parameter. Defaults to None.
        parameters(List, optional): A list of parameter names in the cluster parameter group to reset to the default values. You can't use this parameter if the ResetAllParameters parameter is set to true. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.parameter.group.reset(
                ctx, db_cluster_parameter_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.parameter.group.reset db_cluster_parameter_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="reset_db_cluster_parameter_group",
        op_kwargs={
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "ResetAllParameters": reset_all_parameters,
            "Parameters": parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, account_id: str, vault_name: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation lists all the tags attached to a vault. The operation returns an empty map if there are no tags. For more information about tags, see Tagging Amazon S3 Glacier Resources.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.tags.for_vault.list(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.tags.for_vault.list account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="list_tags_for_vault",
        op_kwargs={"accountId": account_id, "vaultName": vault_name},
    )
